@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/b.c,v 1.12 2014/10/23 16:10:27 tg Exp $ */
+/* $MirOS: contrib/code/jupp/b.c,v 1.15 2016/10/08 17:42:12 tg Exp $ */
 /*
  *	Editor engine
  *	Copyright
@@ -567,7 +567,7 @@ int pgetb(P *p)
 int pgetc(P *p)
 {
 	if (p->b->o.charmap->type) {
-		int val, c, d, n, wid;
+		int val, c, n, wid;
 		/* int m, oc; */
 
 		val = p->valcol;	/* Remember if column number was valid */
@@ -603,14 +603,15 @@ int pgetc(P *p)
 		/* m = n; */
 
 		if (n) {
-			while (n) {
+			int d;
+
+			do {
 				d = brc(p);
 				if (d == NO_MORE_DATA || (d&0xC0)!=0x80)
 					break;
 				pgetb(p);
 				c = ((c<<6)|(d&0x3F));
-				--n;
-			}
+			} while (--n);
 			if (n) { /* FIXME: there was a bad UTF-8 sequence */
 				/* How to represent this? */
 				/* pbkwd(p,m-n);
@@ -2142,7 +2143,9 @@ B *bload(unsigned char *s)
 			mod_time = sbuf.st_mtime;
 		}
 	}
+#if HAVE_BACKSLASH_PATHS
 	joesep(n);
+#endif
 
 	/* Abort if couldn't open */
 	if (!fi) {
@@ -2456,7 +2459,9 @@ int bsave(P *p, unsigned char *s, long int size, int flag)
 		f = fopen((char *)s, "w");
 		norm = 1;
 	}
+#if HAVE_BACKSLASH_PATHS
 	joesep(s);
+#endif
 
 	if (!f) {
 		error = -4;
