@@ -1,7 +1,7 @@
 #if 0
 .if "0" == "1"
 #endif
-/* $MirOS: contrib/code/jupp/charmap.c,v 1.16 2016/10/29 23:44:44 tg Exp $ */
+/* $MirOS: contrib/code/jupp/charmap.c,v 1.19 2017/01/11 22:04:31 tg Exp $ */
 /*
  *	UNICODE/ISO-10646 conversion utilities
  *	Copyright
@@ -88,7 +88,7 @@ static const struct {
 	{ US "cyrillic", US "iso-8859-5" },
 	{ US "arabic", US "iso-8859-6" },
 	{ US "greek", US "iso-8859-7" },
-	{ US "hebrew", US "iso-8859-8" }, /* cp1255 on windows machines? */
+	{ US "hebrew", US "iso-8859-8" },
 	{ US "latin5", US "iso-8859-9" },
 	{ US "turkish", US "iso-8859-9" },
 	{ US "latin6", US "iso-8859-10" },
@@ -97,6 +97,21 @@ static const struct {
 	{ US "latin7", US "iso-8859-13" },
 	{ US "latin8", US "iso-8859-14" },
 	{ US "latin9", US "iso-8859-15" },
+	{ US "cp20127", US "ascii" },
+	{ US "cp20866", US "koi8-r" },
+	{ US "cp21866", US "koi8-u" },
+	{ US "cp28591", US "iso-8859-1" },
+	{ US "cp28592", US "iso-8859-2" },
+	{ US "cp28593", US "iso-8859-3" },
+	{ US "cp28594", US "iso-8859-4" },
+	{ US "cp28595", US "iso-8859-5" },
+	{ US "cp28596", US "iso-8859-6" },
+	{ US "cp28597", US "iso-8859-7" },
+	{ US "cp28598", US "iso-8859-8" },
+	{ US "cp28599", US "iso-8859-9" },
+	{ US "cp28603", US "iso-8859-13" },
+	{ US "cp28605", US "iso-8859-15" },
+	{ US "cp65001", US "utf-8" },
 	{ 0, 0 }
 };
 
@@ -1369,11 +1384,11 @@ find_charmap(const unsigned char *name)
 		if (!map_name_cmp(m->name, name))
 			return (m);
 
-	/* Check ~/.joe/charmaps */
+	/* Check ~/.jupp/charmaps */
 	p = (unsigned char *)getenv("HOME");
 	if (p) {
 		joe_snprintf_2((char *)buf, sizeof(buf),
-		    "%s/.joe/charmaps/%s", p, name);
+		    "%s/.jupp/charmaps/%s", p, name);
 		f = fopen((char *)buf, "r");
 	}
 
@@ -1450,7 +1465,7 @@ get_encodings(void)
 	/* External maps */
 
 	if ((p = (unsigned char *)getenv("HOME"))) {
-		joe_snprintf_1((char *)buf, sizeof(buf), "%s/.joe/charmaps", p);
+		joe_snprintf_1((char *)buf, sizeof(buf), "%s/.jupp/charmaps", p);
 		if (!chpwd(buf) && (t = rexpnd(US "*"))) {
 			for (x = 0; x != aLEN(t); ++x)
 				if (strcmp(t[x], "..")) {
@@ -1517,7 +1532,7 @@ SRCS=		charmap.c
 SRCS+=		i18n.c path.c utf8.c utils.c va.c vs.c
 NOMAN=		Yes
 CPPFLAGS+=	-DTEST -DTEST_CHARMAP
-CPPFLAGS+=	-DJUPP_WIN32RELOC=0 -DJOERC=\"/etc/joe\"
+CPPFLAGS+=	-DJUPP_WIN32RELOC=0 -D'JOERC="/etc/joe"'
 
 .include <bsd.own.mk>
 
