@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/cmd.c,v 1.12 2013/08/19 19:19:30 tg Exp $ */
+/* $MirOS: contrib/code/jupp/cmd.c,v 1.15 2016/10/08 14:58:45 tg Exp $ */
 /*
  *	Command execution
  *	Copyright
@@ -128,11 +128,11 @@ CMD cmds[] = {
 	{US "crawlr", TYPETW + TYPEPW, ucrawlr, NULL, 1, US "crawll"},
 	{US "delbol", TYPETW + TYPEPW + EFIXXCOL + EKILL + EMOD, udelbl, NULL, 1, US "deleol"},
 	{US "delch", TYPETW + TYPEPW + ECHKXCOL + EFIXXCOL + EMINOR + EKILL + EMOD, udelch, NULL, 1, US "backs"},
-	{US "deleol", TYPETW + TYPEPW + EKILL + EMOD, udelel, NULL, 1, US "delbol"}, 
-	{US "dellin", TYPETW + TYPEPW + EFIXXCOL + EKILL + EMOD, udelln, NULL, 1, NULL}, 
+	{US "deleol", TYPETW + TYPEPW + EKILL + EMOD, udelel, NULL, 1, US "delbol"},
+	{US "dellin", TYPETW + TYPEPW + EFIXXCOL + EKILL + EMOD, udelln, NULL, 1, NULL},
 	{US "delw", TYPETW + TYPEPW + EFIXXCOL + ECHKXCOL + EKILL + EMOD, u_word_delete, NULL, 1, US "backw"},
 	{US "dnarw", TYPETW + TYPEPW + EMOVE, udnarw, NULL, 1, US "uparw"},
-	{US "dnarwmenu", TYPEMENU, umdnarw, NULL, 1, US "uparwmenu"}, 
+	{US "dnarwmenu", TYPEMENU, umdnarw, NULL, 1, US "uparwmenu"},
 	{US "dnslide", TYPETW + TYPEPW + TYPEMENU + TYPEQW + EMOVE, udnslide, NULL, 1, US "upslide"},
 	{US "drop", TYPETW + TYPEPW, udrop, NULL, 0, NULL},
 	{US "dupw", TYPETW, uduptw, NULL, 0, NULL},
@@ -163,11 +163,11 @@ CMD cmds[] = {
 	{US "hnext", TYPETW + TYPEPW + TYPEQW, u_help_next, NULL, 0, NULL},
 	{US "hprev", TYPETW + TYPEPW + TYPEQW, u_help_prev, NULL, 0, NULL},
 	{US "insc", TYPETW + TYPEPW + EFIXXCOL + EMOD, uinsc, NULL, 1, US "delch"},
-	{US "insf", TYPETW + TYPEPW + EMOD, uinsf, NULL, 0, NULL}, 
+	{US "insf", TYPETW + TYPEPW + EMOD, uinsf, NULL, 0, NULL},
 	{US "keymap", TYPETW + TYPEPW, ukeymap, NULL, 0, NULL},
 	{US "lindent", TYPETW + TYPEPW + EFIXXCOL + EMOD + EBLOCK, ulindent, NULL, 1, US "rindent"},
 	{US "line", TYPETW + TYPEPW, uline, NULL, 0, NULL},
-	{US "lose", TYPETW + TYPEPW, ulose, NULL, 0, NULL}, 
+	{US "lose", TYPETW + TYPEPW, ulose, NULL, 0, NULL},
 	{US "lower", TYPETW + TYPEPW + EMOD + EBLOCK, ulower, NULL, 0, NULL},
 	{US "ltarw", TYPETW + TYPEPW /* + EFIXXCOL + ECHKXCOL */, u_goto_left, NULL, 1, US "rtarw"},
 	{US "ltarwmenu", TYPEMENU, umltarw, NULL, 1, US "rtarwmenu"},
@@ -181,8 +181,8 @@ CMD cmds[] = {
 	{US "mode", TYPETW + TYPEPW + TYPEQW, umode, NULL, 0, NULL},
 	{US "msg", TYPETW + TYPEPW + TYPEQW + TYPEMENU, umsg, NULL, 0, NULL},
 	{US "nbuf", TYPETW, unbuf, NULL, 1, US "pbuf"},
-	{US "nedge", TYPETW + TYPEPW + EFIXXCOL, unedge, NULL, 1, US "pedge"}, 
-	{US "nextpos", TYPETW + TYPEPW + EFIXXCOL + EMID + EPOS, unextpos, NULL, 1, US "prevpos"}, 
+	{US "nedge", TYPETW + TYPEPW + EFIXXCOL, unedge, NULL, 1, US "pedge"},
+	{US "nextpos", TYPETW + TYPEPW + EFIXXCOL + EMID + EPOS, unextpos, NULL, 1, US "prevpos"},
 	{US "nextw", TYPETW + TYPEPW + TYPEMENU + TYPEQW, unextw, NULL, 1, US "prevw"},
 	{US "nextword", TYPETW + TYPEPW + EFIXXCOL, u_goto_next, NULL, 1, US "prevword"},
 	{US "nmark", TYPETW + TYPEPW, unmark, NULL, 0, NULL},
@@ -192,15 +192,15 @@ CMD cmds[] = {
 	{US "open", TYPETW + TYPEPW + EFIXXCOL + EMOD, uopen, NULL, 1, US "deleol"},
 	{US "parserr", TYPETW, uparserr, NULL, 0, NULL},
 	{US "pbuf", TYPETW, upbuf, NULL, 1, US "nbuf"},
-	{US "pedge", TYPETW + TYPEPW + EFIXXCOL, upedge, NULL, 1, US "nedge"}, 
+	{US "pedge", TYPETW + TYPEPW + EFIXXCOL, upedge, NULL, 1, US "nedge"},
 	{US "pgdn", TYPETW + TYPEPW + TYPEMENU + TYPEQW + EMOVE, upgdn, NULL, 1, US "pgup"},
-	{US "pgdnmenu", TYPEMENU, umpgdn, NULL, 1, US "pgupmenu"}, 
+	{US "pgdnmenu", TYPEMENU, umpgdn, NULL, 1, US "pgupmenu"},
 	{US "pgup", TYPETW + TYPEPW + TYPEMENU + TYPEQW + EMOVE, upgup, NULL, 1, US "pgdn"},
-	{US "pgupmenu", TYPEMENU, umpgup, NULL, 1, US "pgdnmenu"}, 
+	{US "pgupmenu", TYPEMENU, umpgup, NULL, 1, US "pgdnmenu"},
 	{US "picokill", TYPETW + TYPEPW + EFIXXCOL + EKILL + EMOD, upicokill, NULL, 1, NULL},
-	{US "play", TYPETW + TYPEPW + TYPEMENU + TYPEQW, uplay, NULL, 1, NULL},	/* EFIXX? */ 
-	{US "prevpos", TYPETW + TYPEPW + EPOS + EMID + EFIXXCOL, uprevpos, NULL, 1, US "nextpos"}, 
-	{US "prevw", TYPETW + TYPEPW + TYPEMENU + TYPEQW, uprevw, NULL, 1, US "nextw"}, 
+	{US "play", TYPETW + TYPEPW + TYPEMENU + TYPEQW, uplay, NULL, 1, NULL},	/* EFIXX? */
+	{US "prevpos", TYPETW + TYPEPW + EPOS + EMID + EFIXXCOL, uprevpos, NULL, 1, US "nextpos"},
+	{US "prevw", TYPETW + TYPEPW + TYPEMENU + TYPEQW, uprevw, NULL, 1, US "nextw"},
 	{US "prevword", TYPETW + TYPEPW + EFIXXCOL + ECHKXCOL, u_goto_prev, NULL, 1, US "nextword"},
 	{US "prverr", TYPETW, uprverr, NULL, 1, US "nxterr"},
 	{US "psh", TYPETW + TYPEPW + TYPEMENU + TYPEQW, upsh, NULL, 0, NULL},
@@ -213,13 +213,14 @@ CMD cmds[] = {
 	{US "record", TYPETW + TYPEPW + TYPEMENU + TYPEQW, urecord, NULL, 0, NULL},
 	{US "redo", TYPETW + TYPEPW + EFIXXCOL, uredo, NULL, 1, US "undo"},
 	{US "retype", TYPETW + TYPEPW + TYPEMENU + TYPEQW, uretyp, NULL, 0, NULL},
-	{US "rfirst", TYPETW + TYPEPW, prfirst, NULL, 0, NULL}, 
+	{US "rfirst", TYPETW + TYPEPW, prfirst, NULL, 0, NULL},
 	{US "rindent", TYPETW + TYPEPW + EFIXXCOL + EMOD + EBLOCK, urindent, NULL, 1, US "lindent"},
 	{US "run", TYPETW + TYPEPW, urun, NULL, 0, NULL},
 	{US "rsrch", TYPETW + TYPEPW, ursrch, NULL, 0, NULL},
 	{US "rtarw", TYPETW + TYPEPW /* + EFIXXCOL */, u_goto_right, NULL, 1, US "ltarw"}, /* EFIX removed for picture mode */
 	{US "rtarwmenu", TYPEMENU, umrtarw, NULL, 1, US "ltarwmenu"},
 	{US "rtn", TYPETW + TYPEPW + TYPEMENU + TYPEQW + EMOD, urtn, NULL, 1, NULL},
+	{US "rvmatch", TYPETW + TYPEPW + EFIXXCOL, urvmatch, NULL, 0, NULL},
 	{US "save", TYPETW, usave, NULL, 0, NULL},
 	{US "scratch", TYPETW + TYPEPW, uscratch, NULL, 0, NULL},
 	{US "select", TYPETW + TYPEPW, uselect, NULL, 0, NULL},
@@ -241,11 +242,11 @@ CMD cmds[] = {
 	{US "tos", TYPETW + TYPEPW + EMOVE, utos, NULL, 0, NULL},
 	{US "tw0", TYPETW + TYPEPW + TYPEQW + TYPEMENU, utw0, NULL, 0, NULL},
 	{US "tw1", TYPETW + TYPEPW + TYPEQW + TYPEMENU, utw1, NULL, 0, NULL},
-	{US "txt", TYPETW + TYPEPW, utxt, NULL, 0, NULL}, 
+	{US "txt", TYPETW + TYPEPW, utxt, NULL, 0, NULL},
 	{US "type", TYPETW + TYPEPW + TYPEQW + TYPEMENU + EMINOR + EMOD, utype, NULL, 1, US "backs"},
 	{US "undo", TYPETW + TYPEPW + EFIXXCOL, uundo, NULL, 1, US "redo"},
 	{US "uparw", TYPETW + TYPEPW + EMOVE, uuparw, NULL, 1, US "dnarw"},
-	{US "uparwmenu", TYPEMENU, umuparw, NULL, 1, US "dnarwmenu"}, 
+	{US "uparwmenu", TYPEMENU, umuparw, NULL, 1, US "dnarwmenu"},
 	{US "upper", TYPETW + TYPEPW + EMOD + EBLOCK, uupper, NULL, 0, NULL},
 	{US "upslide", TYPETW + TYPEPW + TYPEMENU + TYPEQW + EMOVE, uupslide, NULL, 1, US "dnslide"},
 	{US "yank", TYPETW + TYPEPW + EFIXXCOL + EMOD, uyank, NULL, 1, NULL},
@@ -323,7 +324,7 @@ int execmd(CMD *cmd, int k)
 	else
 		justkilled = 0;
 
-      skip:
+ skip:
 
 	/* Make dislayed cursor column equal the actual cursor column
 	 * for commands which arn't simple vertical movements */
@@ -400,7 +401,8 @@ static int cmdcmplt(BW *bw)
 {
 	if (!scmds)
 		scmds = getcmds();
-	return simple_cmplt(bw,scmds);
+	/*XXX simple_cmplt does p_goto_bol, better only to last comma */
+	return simple_cmplt(bw, scmds);
 }
 
 static int docmd(BW *bw, unsigned char *s, void *object, int *notify)
