@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/help.c,v 1.7 2012/12/30 19:27:13 tg Exp $ */
+/* $MirOS: contrib/code/jupp/help.c,v 1.10 2017/01/10 23:59:32 tg Exp $ */
 /*
  *	Help system
  *	Copyright
@@ -11,6 +11,7 @@
 #include "types.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 
 #ifdef HAVE_BSD_STRING_H
@@ -25,6 +26,8 @@
 #include "utf8.h"
 #include "w.h"
 
+extern void outatr_help(SCRN *,int *,int *,int,int,int,int);
+
 #define NOT_ENOUGH_MEMORY -11
 
 struct help *help_actual = NULL;			/* actual help screen */
@@ -152,7 +155,7 @@ struct help *find_context_help(const unsigned char *name)
 void help_display(SCREEN *t)
 {
 	unsigned char *str;
-	int y, x, c, z;
+	int y, x, z;
 	int atr = 0;
 
 	if (help_actual) {
@@ -260,14 +263,12 @@ void help_display(SCREEN *t)
 						case 0:	
 							--x;
 							continue;
-						default:
-							c = *str++;
 						}
-					} else {
-						c = *str++;
 					}
-					outatr(locale_map, t->t, t->t->scrn + x + y * t->w, 
-					             t->t->attr + x + y * t->w, x, y, c, atr);
+					outatr_help(t->t,
+					    t->t->scrn + x + y * t->w,
+					    t->t->attr + x + y * t->w,
+					    x, y, *str++, atr);
 				}
 			}
 			atr = 0;
