@@ -1,6 +1,6 @@
-/* $MirOS: contrib/code/jupp/main.c,v 1.26 2016/10/29 23:44:45 tg Exp $ */
+/* $MirOS: contrib/code/jupp/main.c,v 1.28 2017/01/11 21:48:58 tg Exp $ */
 
-#define JUPP_IS_COPYRIGHT_C_BY "2016 mirabilos"
+#define JUPP_IS_COPYRIGHT_C_BY "2017 mirabilos"
 
 /*-
  * Copyright (c) 2004ff. Thorsten Glaser
@@ -69,6 +69,10 @@ SCREEN *maint;			/* Main edit screen */
 
 const char null[] = "";
 
+#ifdef __CYGWIN__
+extern unsigned char *cygwin32_cmdline(void);
+#endif
+
 /* Make windows follow cursor */
 
 void dofollows(void)
@@ -280,6 +284,20 @@ int main(int argc, char **argv, char **envp)
 	help_init(s);
 	for (c = 1; argv[c]; ++c) {
 		if (argv[c][0] == '-') {
+#ifdef __CYGWIN__
+			if (!strcmp(argv[c], "-CYGhack")) {
+				s = cygwin32_cmdline();
+				s = strstr(s, "-CYGhack");
+				if (s) {
+					s += /* strlen("-CYGhack") */ 8;
+					while (*s == ' ' || *s == '\t')
+						++s;
+					argv[c] = s;
+					argv[c + 1] = NULL;
+					break;
+				}
+			}
+#endif
 			if (argv[c][1])
 				switch (glopt(argv[c] + 1, argv[c + 1], NULL, 1)) {
 				case 0:
