@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/path.c,v 1.10 2013/08/19 22:48:32 tg Exp $ */
+/* $MirOS: contrib/code/jupp/path.c,v 1.12 2016/10/29 23:44:45 tg Exp $ */
 /* 
  *	Directory and path functions
  *	Copyright
@@ -74,14 +74,16 @@
 #  endif
 #endif
 
-#ifdef __MSDOS__	/* paths in MS-DOS can include a drive letter followed by semicolon */
-#define	do_if_drive_letter(path, command) do { \
-						if ((path)[0] && (path)[1] == ':') { \
-							command; \
-						} \
-					} while(0)
+#if HAVE_DRIVE_LETTERS
+#define do_if_drive_letter(path, command) do {		\
+	if ((path)[1] == ':' && (			\
+	    ((path)[0] >= 'a' && (path)[0] <= 'z') ||	\
+	    ((path)[0] >= 'A' && (path)[0] <= 'Z'))) {	\
+		command;				\
+	}						\
+} while (/* CONSTCOND */ 0)
 #else
-#define do_if_drive_letter(path, command)	do { } while(0)
+#define do_if_drive_letter(path, command) do { } while (/* CONSTCOND */ 0)
 #endif
 #define skip_drive_letter(path)	do_if_drive_letter((path), (path) += 2)
 
@@ -99,6 +101,7 @@
 #endif
 
 /********************************************************************/
+#if HAVE_BACKSLASH_PATHS
 unsigned char *joesep(unsigned char *path)
 {
 	int x;
@@ -108,6 +111,7 @@ unsigned char *joesep(unsigned char *path)
 			path[x] = '/';
 	return path;
 }
+#endif
 /********************************************************************/
 unsigned char *namprt(unsigned char *path)
 {
@@ -382,7 +386,21 @@ unsigned char **rexpnd(unsigned char *word)
 	return lst;
 }
 /********************************************************************/
-int chpwd(unsigned char *path)
+int chJpwd(const unsigned char *path)
+{
+	unsigned char *fullpath;
+	int rv;
+
+	if (!has_JOERC)
+		return (-1);
+	fullpath = vsncpy(NULL, 0, sz(get_JOERC));
+	fullpath = vsncpy(sv(fullpath), sz(path));
+	rv = chpwd(fullpath);
+	vsrm(fullpath);
+	return (rv);
+}
+
+int chpwd(const unsigned char *path)
 {
 #ifdef __MSDOS__
 	unsigned char buf[256];
@@ -438,3 +456,26 @@ unsigned char *pwd(void)
 	return ((void *)wd);
 #endif
 }
+
+#if JUPP_WIN32RELOC
+unsigned char has_JOERC = 0;
+unsigned char *get_JOERC = NULL;
+
+extern char *cygwin32_argv0(void);
+
+void init_JOERC(void)
+{
+	struct stat sb;
+	char *sep;
+
+	if ((get_JOERC = (unsigned char *)cygwin32_argv0()) == NULL)
+		return;
+	joesep(get_JOERC);
+	if ((sep = strrchr((char *)get_JOERC, '/')) == NULL)
+		return;
+	if (stat(get_JOERC, &sb))
+		return;
+	sep[1] = '\0';
+	has_JOERC = 1;
+}
+#endif
