@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/tty.c,v 1.20 2014/07/25 22:10:23 tg Exp $ */
+/* $MirOS: contrib/code/jupp/tty.c,v 1.22 2016/10/30 02:38:35 tg Exp $ */
 /*
  *	UNIX Tty and Process interface
  *	Copyright
@@ -871,7 +871,6 @@ extern char *ptsname(int);
 static unsigned char *getpty(int *ptyfd)
 {
 	int fdm;
-	unsigned char *name;
 
 	*ptyfd = fdm = open("/dev/ptmx", O_RDWR);
 	grantpt(fdm);
@@ -1014,7 +1013,7 @@ MPX *mpxmk(int *ptyfd, const unsigned char *cmd, unsigned char **args, void (*fu
 	int comm[2];
 	pid_t pid;
 	int x;
-	MPX *m;
+	MPX *m = NULL;
 	unsigned char *name;
 
 	/* Get pty/tty pair */
