@@ -1,4 +1,4 @@
-/* $MirOS: contrib/code/jupp/usearch.c,v 1.6 2012/12/22 00:06:15 tg Exp $ */
+/* $MirOS: contrib/code/jupp/usearch.c,v 1.10 2017/01/11 22:56:50 tg Exp $ */
 /*
  *	Search & Replace system
  *	Copyright
@@ -10,6 +10,7 @@
 #include "types.h"
 
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "b.h"
 #include "bw.h"
@@ -474,7 +475,8 @@ static P *insert(SRCH *srch, P *p, unsigned char *s, int len)
 /* Query for search string, search options, possible replacement string,
  * and execute first search */
 
-unsigned char srchstr[] = "Search";	/* Context sensitive help identifier */
+/* Context sensitive help identifier */
+const unsigned char srchstr[] = "Search";
 
 static int pfabort(BW *bw, SRCH *srch)
 {
@@ -753,7 +755,7 @@ static int dopfrepl(BW *bw, int c, SRCH *srch, int *notify)
 
 static int restrict_to_block(BW *bw, SRCH *srch)
 {
-	if (!srch->valid || !srch->block_restrict)
+	if (!srch->block_restrict)
 		return 0;
 	bw->cursor->xcol = piscol(bw->cursor);
 	if (srch->backwards)
@@ -930,7 +932,7 @@ int pfnext(BW *bw)
 	else {
 		SRCH *srch = globalsrch;
 
-		globalsrch = 0;
+		globalsrch = NULL;
 		srch->addr = bw->cursor->byte;
 		if (!srch->wrap_p || srch->wrap_p->b!=bw->b) {
 			prm(srch->wrap_p);
@@ -938,6 +940,7 @@ int pfnext(BW *bw)
 			srch->wrap_p->owner = &srch->wrap_p;
 			srch->wrap_flag = 0;
 		}
+		srch->valid = 0;
 		return dopfnext(bw, setmark(srch), NULL);
 	}
 }
