@@ -1,9 +1,9 @@
-/* $MirOS: contrib/code/jupp/utf8.c,v 1.12 2014/10/23 17:10:45 tg Exp $ */
+/* $MirOS: contrib/code/jupp/utf8.c,v 1.19 2017/01/11 21:48:58 tg Exp $ */
 /*
  *	UTF-8 Utilities
  *	Copyright
  *		(C) 2004 Joseph H. Allen
- *		(c) 2004, 2006 Thorsten Glaser
+ *		(c) 2004, 2006, 2011, 2013, 2014, 2017 Thorsten Glaser
  *
  *	This file is part of JOE (Joe's Own Editor)
  */
@@ -18,15 +18,27 @@
 #include <stdlib.h>
 #endif
 
+#ifdef __CYGWIN__
+#include <cygwin/version.h>
+#endif
+
 #ifdef __MirBSD__
 #include <sys/param.h>
 #endif
 
+#undef USE_CODEPAGE
 #undef USE_LOCALE
 #if defined(HAVE_SETLOCALE) && defined(HAVE_NL_LANGINFO)
 #define USE_LOCALE
 #endif
 
+/* Cygwin before 1.7.2 did not have locale support */
+#if defined(CYGWIN_VERSION_API_MAJOR) && (CYGWIN_VERSION_API_MAJOR < 1) && \
+    defined(CYGWIN_VERSION_API_MINOR) && (CYGWIN_VERSION_API_MINOR < 222)
+#define USE_CODEPAGE
+#undef USE_LOCALE
+#endif
+
 /* OpenBSD, ekkoBSD and old MirOS do not have real locale support */
 #if defined(__OpenBSD__) && (!defined(MirBSD) || (MirBSD < 0x09A0))
 #undef USE_LOCALE
@@ -45,6 +57,10 @@
 #undef USE_LOCALE
 #endif
 
+#ifdef USE_LOCALE
+#undef USE_CODEPAGE
+#endif
+
 #include "rc.h"
 #include "utf8.h"
 #include "charmap.h"
@@ -213,7 +229,9 @@ int utf8_decode_fwrd(unsigned char **p,int *plen)
 
 /* Initialize locale for JOE */
 
-unsigned char *codeset;	/* Codeset of terminal */
+#ifdef USE_CODEPAGE
+extern unsigned int cygwin32_get_cp(void);
+#endif
 
 struct charmap *locale_map;
 			/* Character map of terminal */
@@ -223,31 +241,48 @@ struct charmap *utf8_map;
 void
 joe_locale(void)
 {
+	unsigned char *s;
+
+	s=(unsigned char *)getenv("JOECHARMAP");
+	locale_map = find_charmap(s);
 #if !defined(USE_LOCALE)
-	unsigned char *s, *t;
-
-
-	s=(unsigned char *)getenv("LC_ALL");
-	if (!s) {
-		s=(unsigned char *)getenv("LC_CTYPE");
+	if (!locale_map) {
+		s=(unsigned char *)getenv("LC_ALL");
 		if (!s) {
-			s=(unsigned char *)getenv("LANG");
+			s=(unsigned char *)getenv("LC_CTYPE");
+			if (!s) {
+				s=(unsigned char *)getenv("LANG");
+			}
 		}
+#ifdef USE_CODEPAGE
+		/* if LC_* are unset, use codepage */
+		if (!s) {
+			char buf[16];
+
+			joe_snprintf_1(buf, sizeof(buf), "cp%u", cygwin32_get_cp());
+			locale_map = find_charmap(buf);
+		}
+#endif
 	}
 #endif
 
 #ifdef USE_LOCALE
-	setlocale(LC_ALL,"");
-	codeset = (unsigned char *)strdup(nl_langinfo(CODESET));
+	if (!locale_map) {
+		setlocale(LC_ALL,"");
+		s = (unsigned char *)strdup(nl_langinfo(CODESET));
 
-	locale_map = find_charmap(codeset);
+		locale_map = find_charmap(s);
+	}
 #else
-	if (s == NULL) {
-		locale_map = NULL;
-	} else {
-		if ((t = strrchr(s, '.')) != NULL)
-			locale_map = find_charmap(++t);
-		if (locale_map == NULL)
+	if (!locale_map && s) {
+		unsigned char *t, *tt;
+
+		if ((t = strrchr(s, '.')) != NULL) {
+			if ((tt = strchr(++t, '@')) != NULL)
+				*tt = '\0';
+			locale_map = find_charmap(t);
+		}
+		if (!locale_map)
 			locale_map = find_charmap(s);
 	}
 #endif
